<?php
if (!defined('ABSPATH'))
    exit; // Exit if accessed directly

/*------------------------------GoCargo Post Type------------------------------*/
add_action( 'init', 'gocargo_shipment_init' );
/**
 * Register a gocargo_shipment post type.
 */
function gocargo_shipment_init() {
	$labels = array(
		'name'               => esc_html__( 'Shipment', 'post type general name', 'gocargo-shipment' ),
		'singular_name'      => esc_html__( 'Shipment', 'post type singular name', 'gocargo-shipment' ),
		'menu_name'          => esc_html__( 'GOCargo Shipment', 'admin menu', 'gocargo-shipment' ),
		'name_admin_bar'     => esc_html__( 'Shipment', 'add new on admin bar', 'gocargo-shipment' ),
		'add_new'            => esc_html__( 'Add Shipment', 'gocargo_shipment', 'gocargo-shipment' ),
		'add_new_item'       => esc_html__( 'Add New Shipment', 'gocargo-shipment' ),
		'new_item'           => esc_html__( 'New Shipment', 'gocargo-shipment' ),
		'edit_item'          => esc_html__( 'Edit Shipment', 'gocargo-shipment' ),
		'view_item'          => esc_html__( 'View Shipment', 'gocargo-shipment' ),
		'all_items'          => esc_html__( 'All Shipment', 'gocargo-shipment' ),
		'search_items'       => esc_html__( 'Search Shipment', 'gocargo-shipment' ),
		'parent_item_colon'  => esc_html__( 'Parent Shipment:', 'gocargo-shipment' ),
		'not_found'          => esc_html__( 'No shipment found.', 'gocargo-shipment' ),
		'not_found_in_trash' => esc_html__( 'No shipment found in Trash.', 'gocargo-shipment' )
	);

	$args = array(
		'labels'             => $labels,
        'description'        => esc_html__( 'Description.', 'gocargo-shipment' ),
		'public'             => true,
		'publicly_queryable' => true,
		'show_ui'            => true,
		'show_in_menu'       => true,
		'query_var'          => true,
		'rewrite'            => array( 'slug' => 'gocargo_shipment' ),
		'capability_type'    => 'post',
		'has_archive'        => true,
		'hierarchical'       => false,
		'menu_position'      => null,
		'menu_icon' => 'dashicons-location-alt',
		'supports'           => array( 'title', 'author', 'thumbnail' ),		
	);

	register_post_type( 'gocargo_shipment', $args );
}

// hook into the init action and call gocargo_shipment_taxonomies when it fires
add_action( 'init', 'gocargo_shipment_taxonomies', 0 );

// create two taxonomies, genres and writers for the post type "gocargo_shipment"
function gocargo_shipment_taxonomies() {
	// Add new taxonomy, make it hierarchical (like categories)
	$labels = array(
		'name'              => esc_html__( 'Shipment Categories', 'taxonomy general name' ),
		'singular_name'     => esc_html__( 'Shipment Category', 'taxonomy singular name' ),
		'search_items'      => esc_html__( 'Search Shipment Categories' ),
		'all_items'         => esc_html__( 'All Shipment Categories' ),
		'parent_item'       => esc_html__( 'Parent Shipment Category' ),
		'parent_item_colon' => esc_html__( 'Parent Shipment Category:' ),
		'edit_item'         => esc_html__( 'Edit Shipment Category' ),
		'update_item'       => esc_html__( 'Update Shipment Category' ),
		'add_new_item'      => esc_html__( 'Add New Shipment Category' ),
		'new_item_name'     => esc_html__( 'New Shipment Category Name' ),
		'menu_name'         => esc_html__( 'Shipment Category' ),
	);

	$args = array(
		'hierarchical'      => true,
		'labels'            => $labels,
		'show_ui'           => true,
		'show_admin_column' => true,
		'query_var'         => true,
		'rewrite'           => array( 'slug' => 'gocargo_shipment_cate' ),
	);

	register_taxonomy( 'gocargo_shipment_cate', array( 'gocargo_shipment' ), $args );

	// Add new taxonomy, NOT hierarchical (like tags)
	$labels = array(
		'name'                       => esc_html__( 'Tags', 'taxonomy general name' ),
		'singular_name'              => esc_html__( 'Tag', 'taxonomy singular name' ),
		'search_items'               => esc_html__( 'Search Tags' ),
		'popular_items'              => esc_html__( 'Popular Tags' ),
		'all_items'                  => esc_html__( 'All Tags' ),
		'parent_item'                => null,
		'parent_item_colon'          => null,
		'edit_item'                  => esc_html__( 'Edit Tag' ),
		'update_item'                => esc_html__( 'Update Tag' ),
		'add_new_item'               => esc_html__( 'Add New Tag' ),
		'new_item_name'              => esc_html__( 'New Tag Name' ),
		'separate_items_with_commas' => esc_html__( 'Separate tags with commas' ),
		'add_or_remove_items'        => esc_html__( 'Add or remove tags' ),
		'choose_from_most_used'      => esc_html__( 'Choose from the most used tags' ),
		'not_found'                  => esc_html__( 'No tags found.' ),
		'menu_name'                  => esc_html__( 'Shipment Tags' ),
	);

	$args = array(
		'hierarchical'          => false,
		'labels'                => $labels,
		'show_ui'               => true,
		'show_admin_column'     => true,
		'update_count_callback' => '_update_post_term_count',
		'query_var'             => true,
		'rewrite'               => array( 'slug' => 'gocargo_shipment_tags' ),
	);

	register_taxonomy( 'gocargo_shipment_tags', 'gocargo_shipment', $args );
}